sqltriples.Types.BNode

Package sqltriples :: Module Types :: Class BNode |
[show private | hide private]
[frames | no frames]

## Class BNode

A BNode compatible with the rdflib class of the same name.

Method Summary
| `__init__(self, value)`
| `__eq__(self, other)`
| `__hash__(self)`
| `__ne__(self, other)`
| `__repr__(self)`
| `__unicode__(self)`

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net